@@ -87,3 +87,16 @@ def _u_sub(a):
 
 def _if_exp(t,b,o):
     return b if t else o
+
+def _subscript(a, b):
+    return a[b]
+
+def _list(*args):
+    return args
+
+def _tuple(*args):
+    return tuple(args)
+
+def _dict(*args):
+    n = len(args)/2
+    return {k: v for k, v in zip(args[:n], args[n:])}
